@@ -13,8 +13,8 @@ describe WPScan::Finders::Medias::AttachmentBruteForcing do
   describe '#target_urls' do
     it 'returns the expected urls' do
       expect(finder.target_urls(range: (1..2))).to eql(
-        url + '?attachment_id=1' => 1,
-        url + '?attachment_id=2' => 2
+        "#{url}?attachment_id=1" => 1,
+        "#{url}?attachment_id=2" => 2
       )
     end
   end
