@@ -12,11 +12,11 @@ shared_examples WPScan::Target::Platform::WordPress do
 
     before do
       stub_request(:get, target.url).to_return(body: File.read(fixtures.join("#{homepage}.html")))
-      stub_request(:get, ERROR_404_URL_PATTERN).to_return(body: File.read(fixtures.join("#{page_404}.html")))
+      stub_request(:get, ERROR_404_URL_PATTERN).to_return(body: File.read(fixtures.join("#{page404}.html")))
     end
 
     context 'when pattern/s in the homepage' do
-      let(:page_404) { 'not_wp' }
+      let(:page404) { 'not_wp' }
 
       %w[default wp_includes only_scripts meta_generator comments mu_plugins wp_admin wp_json_oembed].each do |file|
         context "when a wordpress page (#{file}.html)" do
@@ -35,7 +35,7 @@ shared_examples WPScan::Target::Platform::WordPress do
       context 'when pattern/s in the 404 page' do
         %w[default wp_includes only_scripts meta_generator comments mu_plugins wp_admin wp_json_oembed].each do |file|
           context "when a wordpress page (#{file}.html)" do
-            let(:page_404) { file }
+            let(:page404) { file }
 
             it 'returns true' do
               expect(subject.wordpress?(:mixed)).to be true
@@ -45,7 +45,7 @@ shared_examples WPScan::Target::Platform::WordPress do
       end
 
       context 'when no clues in the 404 page' do
-        let(:page_404) { 'not_wp' }
+        let(:page404) { 'not_wp' }
 
         context 'when only passive detection mode' do
           it 'returns false' do
